<?php
session_start();

class User extends Controller
{
    public function index($page = 1)
    {
        try {
            // Check if the user is logged in as 'user'
            if (isset($_SESSION['user_role']) && $_SESSION['user_role'] === 'user') {
                $limit = 10;
                $page = intval($page);
                $offset = ($page - 1) * $limit;
                $offset = intval($offset);
                $data['book'] = $this->model('BookModel')->getAllBookList($limit, $offset);

                $this->view('library/booklist', $data);
            } else {
                throw new Exception("Unauthorized access.");
            }
        } catch (Exception $e) {
            $error_message = $e->getMessage();
            $this->view('error/403', ['error' => $error_message]);
        }
    }

    public function bookmark($page = 1)
    {
        try {
            if (isset($_SESSION['user_role']) && $_SESSION['user_role'] === 'user') {
                $limit = 10;
                $offset = ($page - 1) * $limit;
                $data['book'] = $this->model('BookModel')->getAllBookmark($limit, $offset);
                $this->view('bookmark/bookmark', $data);
            } else {
                throw new Exception("Unauthorized access.");
            }
        } catch (Exception $e) {
            $error_message = $e->getMessage();
            $this->view('error/403', ['error' => $error_message]);
        }
    }

    public function addbookmark()
    {
        try {
            if (isset($_SESSION['user_role']) && $_SESSION['user_role'] === 'user') {
                // Check if 'id' and 'bookid' were sent via POST
                if (isset($_POST['id']) && isset($_POST['bookid'])) {
                    // Access the 'id' and 'bookid' values from $_POST
                    $id = $_POST['id'];
                    $bookid = $_POST['bookid'];

                    $this->model('BookModel')->addBookmark($id, $bookid);
                    $this->bookdetail($bookid);
                } else {
                    throw new Exception("Invalid request.");
                }
            } else {
                throw new Exception("Unauthorized access.");
            }
        } catch (Exception $e) {
            $error_message = $e->getMessage();
            $this->view('error/403', ['error' => $error_message]);
        }
    }

    public function deletebookmark()
    {
        try {
            if (isset($_SESSION['user_role']) && $_SESSION['user_role'] === 'user') {
                // Check if 'id' and 'bookid' were sent via POST
                if (isset($_POST['id']) && isset($_POST['bookid'])) {
                    // Access the 'id' and 'bookid' values from $_POST
                    $id = $_POST['id'];
                    $bookid = $_POST['bookid'];

                    $this->model('BookModel')->deleteBookmark($id, $bookid);
                    $this->bookmark();
                } else {
                    throw new Exception("Invalid request.");
                }
            } else {
                throw new Exception("Unauthorized access.");
            }
        } catch (Exception $e) {
            $error_message = $e->getMessage();
            $this->view('error/403', ['error' => $error_message]);
        }
    }

    public function bookdetail($page = 1)
    {
        try {
            if (isset($_SESSION['user_role']) && $_SESSION['user_role'] === 'user') {
                $data['book'] = $this->model('BookModel')->getBookDetail($page);
                $data['path'] = $this->model('BookModel')->getBookFilename($page);
                $this->view('library/detailbook', $data);
            } else {
                throw new Exception("Unauthorized access.");
            }
        } catch (Exception $e) {
            $error_message = $e->getMessage();
            $this->view('error/403', ['error' => $error_message]);
        }
    }

    public function bookmarkSearch($page = 1)
    {
        try {
            if (isset($_SESSION['user_role']) && $_SESSION['user_role'] === 'user') {
                if ($_SERVER['REQUEST_METHOD'] === 'POST') {
                    $searchInput = isset($_POST['search']) ? $_POST['search'] : '';
                    $sortSelect = isset($_POST['sortSelect']) ? $_POST['sortSelect'] : 'title';
                    $sortOrder = isset($_POST['sortOrder']) ? $_POST['sortOrder'] : 'ASC';
                    $filterSelect = isset($_POST['filterSelect']) ? $_POST['filterSelect'] : 'none';
                    $filterQuery = isset($_POST['filterQuery']) ? $_POST['filterQuery'] : '';
                    
                    $limit = 10;
                    $page = intval($page);
                    $offset = ($page - 1) * $limit;
                    $offset = intval($offset);
                    // Perform a search using the parameters and the model method
                    $data['book'] = $this->model('BookModel')->searchBookmark($searchInput, $sortSelect, $sortOrder, $filterSelect, $filterQuery, $limit, $offset);
                    if (empty($data['book'])) {
                        $data['message'] = 'No results found.';
                    }
                    $this->view('bookmark/bookmark', $data);
                } else {
                    throw new Exception("Invalid request.");
                }
            } else {
                throw new Exception("Unauthorized access.");
            }
        } catch (Exception $e) {
            $error_message = $e->getMessage();
            $this->view('error/403', ['error' => $error_message]);
        }
    }

    public function booklistSearch($page = 1)
    {
        try {
            if (isset($_SESSION['user_role']) && $_SESSION['user_role'] === 'user') {
                if ($_SERVER['REQUEST_METHOD'] === 'POST') {
                    $searchInput = isset($_POST['search']) ? $_POST['search'] : '';
                    $sortSelect = isset($_POST['sortSelect']) ? $_POST['sortSelect'] : 'title';
                    $sortOrder = isset($_POST['sortOrder']) ? $_POST['sortOrder'] : 'ASC';
                    $filterSelect = isset($_POST['filterSelect']) ? $_POST['filterSelect'] : 'none';
                    $filterQuery = isset($_POST['filterQuery']) ? $_POST['filterQuery'] : '';
                    
                    $limit = 10;
                    $page = intval($page);
                    $offset = ($page - 1) * $limit;
                    $offset = intval($offset);
                    // Perform a search using the parameters and the model method
                    $data['book'] = $this->model('BookModel')->searchBookList($searchInput, $sortSelect, $sortOrder, $filterSelect, $filterQuery, $limit, $offset);
                    $this->view('library/booklist', $data);
                } else {
                    $limit = 10;
                    $page = intval($page);
                    $offset = ($page - 1) * $limit;
                    $offset = intval($offset);
                    $data['book'] = $this->model('BookModel')->getAllBookList($limit, $offset);
                    if (empty($data['book'])) {
                        $data['message'] = 'No results found.';
                    }
                    $this->view('library/booklist', $data);
                }
            } else {
                throw new Exception("Unauthorized access.");
            }
        } catch (Exception $e) {
            $error_message = $e->getMessage();
            $this->view('error/403', ['error' => $error_message]);
        }
    }
}