<?php
require_once('tables.php');

class Database
{
    private $host = HOST;
    private $db_name = DBNAME;
    private $user = USER;
    private $password = PASSWORD;
    private $port = PORT;

    private $dbs;
    private $statement;

    public function __construct()
    {
        $dsn = 'mysql:host=' . $this->host . ';port=' . $this->port . ';dbname=' . $this->db_name;

        $option = [
            PDO::ATTR_PERSISTENT => true,
            PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION
        ];

        try {
            $this->dbs = new PDO($dsn, $this->user, $this->password, $option);
           //  $this->dbs->exec("USE audiolibs");

        } catch (PDOException $e) {
            die($e->getMessage());
        }

        try {
            $this->dbs->exec(Tables::AUTHOR_TABLE);
            $this->dbs->exec(Tables::USER_TABLE);
            $this->dbs->exec(Tables::BOOK_TABLE);
            $this->dbs->exec(Tables::INVENTORY_TABLE);
            
            } catch (PDOException $e) {
                die($e->getMessage());
        }
    }

    public function query($query){
        $this->statement = $this->dbs->prepare($query);
    }

    public function bind($param, $value, $type = null)
    {
        if( is_null($type) ) {
            switch( true ) {
                case is_int($value) :
                    $type = PDO::PARAM_INT;
                    break;
                case is_bool($value) :
                    $type = PDO::PARAM_BOOL;
                    break;
                case is_null($value) :
                    $type = PDO::PARAM_NULL;
                    break;
                default:
                    $type = PDO::PARAM_STR;
            }
        }

        $this->statement->bindValue($param, $value, $type);
    }

    public function execute()
    {
        $this->statement->execute();
    }

    public function resultSet(){
        $this->execute();
        return $this->statement->fetchAll(PDO::FETCH_ASSOC);
    }

    public function single(){
        $this->execute();
        return $this->statement->fetch(PDO::FETCH_ASSOC);
    }

    public function rowCount()
    {
        try {
            return $this->statement->rowCount();
        } catch (PDOException $e) {
            die($e->getMessage());
        }
    }
}